@@ -7,7 +7,7 @@ import (
 	"time"
 
 	"github.com/cloudentity/oauth2c/internal/oauth2"
-	"github.com/pkg/browser"
+	"github.com/cli/browser"
 )
 
 func (c *OAuth2Cmd) DeviceGrantFlow(clientConfig oauth2.ClientConfig, serverConfig oauth2.ServerConfig, hc *http.Client) error {
